@@ -22,7 +22,6 @@ _UUID_TO_COLOR: Final = {
 
 
 class TiltBluetoothDeviceData(BluetoothData):
-
     """Data update for Tilt Bluetooth devices"""
 
     def _start_update(self, service_info: BluetoothServiceInfo) -> None:
@@ -37,7 +36,7 @@ class TiltBluetoothDeviceData(BluetoothData):
         try:
             data = manufacturer_data[76]
         except KeyError:
-            _LOGGER.warning("Manufacturer ID 76 not found in data")
+            _LOGGER.debug("Manufacturer ID 76 not found in data")
             return
 
         if data[0] != 0x02 or data[1] != 0x15:
@@ -53,8 +52,6 @@ class TiltBluetoothDeviceData(BluetoothData):
             return
 
         self.set_device_manufacturer("Tilt")
-        self.set_device_type(color)
-        self.set_device_name(f"Tilt {color}")
 
         (major, minor, power) = unpack(">hhb", data[18:23])
 
@@ -62,11 +59,20 @@ class TiltBluetoothDeviceData(BluetoothData):
         if not changed_manufacturer_data:
             return
 
-        temperature = major
-        specific_gravity = minor / 1000
+        tilt_pro = minor >= 5000
+
+        self.set_device_type(f"Pro {color}" if tilt_pro else color)
+        self.set_device_name(f"Tilt Pro {color}" if tilt_pro else f"Tilt {color}")
+
+        # up the scale rate if a tilt pro
+        temp_scalar = 10 if tilt_pro else 1
+        grav_scalar = 10000 if tilt_pro else 1000
+
+        temperature = major / temp_scalar
+        specific_gravity = minor / grav_scalar
 
         _LOGGER.debug(
-            "Tilt %s data: temp=%.2f, gravity=%.2f, power=%.2f",
+            "Tilt %s data: temp=%.3f, gravity=%.3f, power=%.2f",
             color,
             temperature,
             specific_gravity,
